function gameUpdate(dt)
  screen:update(dt)
  bgm:play()
  objects.player.update(world, dt)
  sprites.player.update(objects.player.x+16, objects.player.y-2, 2)

  cam.x = winW/2
  cam.y = sprites.player.y
  if cam.y + winH/2 > winH/2 then
    cam.y = 0
  elseif cam.y < -5121 then
    cam.y = -5121
  end

  for i=1,#objects.spikes do
    local spike = objects.spikes[i]
    if CheckCollisionBtwRects(objects.player, spike) then
      hurtSound:stop()
      hurtSound:play()
      screen:shake(30)
      objects.player.respawn(world, 32*14/2, 267)
      lives = lives - 1
    end
  end

  if CheckCollisionBtwRects(objects.player, finishRect) then
    scoreFlag = true
  end

  if not CheckCollisionBtwRects(objects.player, finishRect) and not scoreFlag then
    if currentScoreTime >= scoreCoolTime then
      score = score + 1
    else
      currentScoreTime = currentScoreTime + dt
    end
  end

  if lives < 1 then
    mapModule.removeObjects(world)
    Restart()
    bgm:stop()
    gameState = "startMenu"
    screen:shake(30)
  end

end

function gameDraw()
  cam:attach()
  screen:apply()
  love.graphics.setColor(1, 1, 1)
  if scoreFlag then
    love.graphics.setFont(finishFont)
    love.graphics.print("Finished in "..tostring(score/100).." secs \nPress 'r' to restart \nPress 'esc' to go back to main menu", 50, -5321, 0, 1, 1, 0, 32)
    --love.graphics.print("Easter egg! :D", winW/2, winH-64)
    --love.graphics.print()
  end
  mapModule.drawMaps(objects.maps)
  sprites.player.draw()
  cam:detach()

  local heartPosX = -10
  --20*19
  local interval = 45
  for i=1,lives do
    love.graphics.draw(heartImg, heartPosX, -10, 0, 2, 2)
    heartPosX = heartPosX + interval
  end

  if not scoreFlag then
    love.graphics.setFont(scoreFont)
    love.graphics.print(string.format("%.2f", score/100), winW/2, 10, 0, 1, 1, (#tostring(score)-1)*16, 0)
  end

  --love.graphics.print(tostring(math.floor(objects.player.x)).." "..tostring(math.floor(objects.player.y)), 0, winH/2)
  --(32, -5269) (224, -5373)
end

function gameInput(key)
  objects.player.jump(key == "up" or key == "w", 425)
  if key == "r" then
    bgm:stop()
    mapModule.removeObjects(world)
    Restart()
    screen:shake(30)
  elseif key == "escape" then
    mapModule.removeObjects(world)
    bgm:stop()
    Restart()
    gameState = "startMenu"
  end
end
