local module = {}

function module.loadObjects(tileMap, offsetY, platforms)
  local objects = tileMap.layers[2].objects
  for i=1,#objects do
    local object = objects[i]
    --local objTable = PlatformClass.new(object.x, object.y+offsetY, object.width, object.height)
    local objTable = {
                      x=object.x,
                      y=object.y,
                      w=object.width,
                      h=object.height
                      }
    function objTable.destroy(world)
      if world:hasItem(objTable) then
        world:remove(objTable)
      end
    end

    table.insert(platforms, objTable)
    world:add(objTable, objTable.x, object.y+offsetY, objTable.w, objTable.h)
  end
end

function module.removeObjects(world)
  for i=1,#objects.platforms do
    local platform = objects.platforms[i]
    platform.destroy(world)
  end
end

function module.drawTiles(tileMap, offsetY)
  local tiles = tileMap.layers[1].data
  for rowIndex=1,#tiles do
    for columnIndex=1,#tiles[rowIndex] do
      local tile = tiles[rowIndex][columnIndex]
      if tile == 1 then
        love.graphics.draw(groundTileImg, (columnIndex-1)*32, (rowIndex-1)*32+offsetY)
      elseif tile ~= 0 then
        love.graphics.draw(spikeTileImg, (columnIndex-1)*32, (rowIndex-1)*32+offsetY)
      end
    end
  end
end

function module.loadSpikes(tileMap, offsetY)
  local tiles = tileMap.layers[1].data
  for rowIndex=1,#tiles do
    for columnIndex=1,#tiles[rowIndex] do
      local tile = tiles[rowIndex][columnIndex]
      if tile ~= 1 and tile ~= 0 then
        local spike = {
          x = (columnIndex-1)*32,
          y = (rowIndex-1)*32+offsetY,
          w = 32,
          h = 32
        }
        table.insert(objects.spikes, spike)
      end
    end
  end
end

function module.getMaps(mapNums)
  for i=1,#mapNums do
    local mapNum = mapNums[i]
    local map = intervalMaps[mapNum]
    table.insert(objects.maps, map)
  end
end

function module.loadMaps(maps)
  local offsetY = 0
  for i=1,#objects.maps do
    local map = objects.maps[i]
    module.loadObjects(map, offsetY, objects.platforms)
    module.loadSpikes(map, offsetY)
    offsetY = offsetY - 32*10
  end
end

function module.drawMaps(maps)
  local offsetY = 0
  for i=1,#objects.maps do
    local map = objects.maps[i]
    module.drawTiles(map, offsetY)
    offsetY = offsetY - 32*10
  end
end

return module
