local player = {}

function player.new(x, y, w, h)
  player.x = x
  player.y = y
  player.w = w
  player.h = h
  player.xv = 0
  player.yv = 0
  player.onGround = false
  return player
end

function player.update(world, dt)
  player.move(20, 0.925, dt)
  player.gravity(895, dt)
  player.collide(world, dt)
end

function player.move(speed, friction, dt)
  if love.keyboard.isDown("left") or love.keyboard.isDown("a") then
    player.xv = player.xv - speed
  elseif love.keyboard.isDown("right") or love.keyboard.isDown("d") then
    player.xv = player.xv + speed
  end
  player.xv = player.xv * friction
end

function player.gravity(grv, dt)
  player.yv = player.yv + grv*dt
end

function player.collide(world, dt)
  player.onGround = false
  local goalX = player.x + player.xv*dt
  local goalY = player.y + player.yv*dt
  local nextX, nextY, cols, len = world:move(player, goalX, goalY)

  for i=1,len do
    local col = cols[i]
    if col.normal.y == 1 or col.normal.y == -1 then
      player.yv = 0
    end
    if col.normal.x == 1 or col.normal.x == -1 then
      player.xv = 0
    end
    if col.normal.y == -1 then
      player.onGround = true
    end
  end

  player.x = nextX
  player.y = nextY
end

function player.jump(condition, jumpSpeed)
  if condition and player.onGround then
    jumpSound:stop()
    jumpSound:play()
    player.yv = -jumpSpeed
  end
end

function player.respawn(world, x, y)
  world:update(player, x, y)
  player.x = winW/2
end

function player.draw()
  love.graphics.setColor(1, 1, 0)
  love.graphics.rectangle("line", player.x, player.y, player.w, player.h)
end

return player
