bump = require "Libs.bump"
camera = require "Libs.camera"
screen = require "Libs.shack"

PlatformerPlayerClass = require "Objects.PlatformerPlayer"
PlayerSpriteClass = require "Objects.PlayerSprite"
PlatformClass = require "Objects.Platform"
mapModule = require "Objects.MapLoadAndDraw"

local tutorial = require "Tilemaps.Tutorial"
local part1 = require "Tilemaps.Part1"
local part2 = require "Tilemaps.Part2"
local part3 = require "Tilemaps.Part3"
local part4 = require "Tilemaps.Part4"
local part5 = require "Tilemaps.Part5"
local part6 = require "Tilemaps.Part6"
local part7 = require "Tilemaps.Part7"
local part8 = require "Tilemaps.Part8"
local part9 = require "Tilemaps.Part9"
local part10 = require "Tilemaps.Part10"
local theEnd = require "Tilemaps.End"

require "GameStates.game"
require "GameStates.startMenu"

world = bump.newWorld()

winW = 32*14
winH = 32*20
cam = camera(winW/2, 0)

function CheckCollision(x1,y1,w1,h1, x2,y2,w2,h2)
  return x1 < x2+w2 and
         x2 < x1+w1 and
         y1 < y2+h2 and
         y2 < y1+h1
end

function CheckCollisionBtwRects(a, b)
  return CheckCollision(a.x,a.y,a.w,a.h, b.x,b.y,b.w,b.h)
end

function Restart()
  currentScoreTime = 0
  scoreCoolTime = 0.01
  score = 0.00
  scoreFlag = false

  objects = {}
  sprites = {}
  intervalMaps = {part1, part2, part3, part4, part5, part6, part7, part8, part9, part10}

  objects.player = PlatformerPlayerClass.new(winW/2, winH/2-32-25, 16*2, 10*2+1)
  sprites.player = PlayerSpriteClass.new(objects.player.x, objects.player.y, 2, 2)
  if not world:hasItem(objects.player) then
    world:add(objects.player, objects.player.x, objects.player.y, objects.player.w, objects.player.h)
  end
  objects.player.respawn(world, 32*14/2, 267)
  lives = 3

  objects.spikes = {}
  objects.platforms = {}
  objects.particles = {}

  objects.maps = {tutorial}
  objects.mapNums = {}

  for i=1,16 do
    local mapNum = love.math.random(1, 10)
    table.insert(objects.mapNums, mapNum)
  end
  mapModule.getMaps(objects.mapNums)
  table.insert(objects.maps, theEnd)
  mapModule.loadMaps(objects.maps)

end

function love.load()
  plays = 0
  love.graphics.setBackgroundColor(16/255, 7/255, 63/255)
  love.graphics.setDefaultFilter("nearest", "nearest")

  playerImg = love.graphics.newImage("Images/Player.png")
  groundTileImg = love.graphics.newImage("Images/Tile.png")
  spikeTileImg = love.graphics.newImage("Images/Spike.png")
  heartImg = love.graphics.newImage("Images/Heart.png")

  titleFont = love.graphics.newFont("Fonts/lunchds.ttf", 64)
  scoreFont = love.graphics.newFont("Fonts/lunchds.ttf", 32)
  finishFont = love.graphics.newFont("Fonts/lunchds.ttf", 16)

  jumpSound = love.audio.newSource("Sounds/Jump.wav", "static")
  jumpSound:setVolume(0.5)
  hurtSound = love.audio.newSource("Sounds/Hurt.wav", "static")
  bgm = love.audio.newSource("Sounds/BGM.wav", "stream")
  bgm:setVolume(0.8)

  screen:setDimensions(winW, winH)
  finishRect = {x=32, y=-5373, w=192, h=114}
  gameState = "startMenu"

  Restart()
  --mapModule.loadMaps(objects.maps)
end

function love.update(dt)

  if gameState == "game" then
    gameUpdate(dt)
  end

end

function love.draw()
  if gameState == "game" then
    gameDraw()
  elseif gameState == "startMenu" then
    startMenuDraw()
  end
end

function love.keypressed(key, scancode, isrepeat)
  if gameState == "game" then
    gameInput(key)
  elseif gameState == "startMenu" then
    startMenuInput(key)
  end
end
